using System;
using System.IO;
using NUnit.Framework;

namespace SampleApp.Tests
{
    [TestFixture]
    public class LetterGeneratorTest
    {
        [Test]
        public void CanWriteLetter()
        {
            string firstName = "Bill";
            string lastName = "Johnson";

            // check if path exists
            if (!Directory.Exists(AppSettings.LetterPath))
            {
                Directory.CreateDirectory(AppSettings.LetterPath);
            }

            // make sure file isn't already there
            string filename = String.Format("{0}{1}.txt", firstName, lastName);
            filename = AppSettings.LetterPath + filename;
            if (File.Exists(filename))
            {
                File.Delete(filename);
            }

            try
            {
                //create letter generator
                var letterGenerator = new LetterGenerator();
                letterGenerator.FirstName = firstName;
                letterGenerator.LastName = lastName;
                letterGenerator.LetterTemplate = "Hello {FirstName} {LastName}";
                letterGenerator.WriteLetter();

                //check if file was created
                if (!File.Exists(filename))
                {
                    Assert.Fail("File did not get written!");
                }

                //get file contents
                string fileContents;
                using (var streamReader = new StreamReader(filename))
                {
                    fileContents = streamReader.ReadToEnd();
                }

                //assert!
                Assert.AreEqual("Hello Bill Johnson", fileContents);
            }
            finally
            {
                // clean up
                if (File.Exists(filename))
                {
                    File.Delete(filename);
                }
            }
        }
    }
}